package main

import (
	"testing"

	"github.com/stretchr/testify/assert"
)

func TestBug(t *testing.T) {
	t.Run("WHEN calling save twice THEN values are saved on unexpected cells", func(t *testing.T) {
		{
			file := OpenExcel(FILE)
			ExportDataFoo(file)
			ExportDataBar(file)

			file.Close()
		}

		{
			file := OpenExcel(FILE_EDITED)

			// This two test will work because this was saved with the first save call
			value, err := file.GetCellValue(SHEET_NAME, CELL_B3)
			assert.Nil(t, err)
			assert.Equal(t, "TestValueB3", value)

			value, err = file.GetCellValue(SHEET_NAME, CELL_B4)
			assert.Nil(t, err)
			assert.Equal(t, "TestValueB4", value)

			// This won't work because was saved after first save call
			value, err = file.GetCellValue(SHEET_NAME, CELL_Z12)
			assert.Nil(t, err)
			assert.Equal(t, "TestValueZ12", value)

			file.Close()
		}
	})

	t.Run("WHEN calling save once THEN values are saved on expected cells", func(t *testing.T) {
		{
			file := OpenExcel(FILE)
			ExportDataFooWithoutSave(file)
			ExportDataBar(file)

			file.Close()
		}

		{
			file := OpenExcel(FILE_EDITED)

			// This two test will work because this was saved with the first save call
			value, err := file.GetCellValue(SHEET_NAME, CELL_B3)
			assert.Nil(t, err)
			assert.Equal(t, "TestValueB3", value)

			value, err = file.GetCellValue(SHEET_NAME, CELL_B4)
			assert.Nil(t, err)
			assert.Equal(t, "TestValueB4", value)

			// This won't work because was saved after first save call
			value, err = file.GetCellValue(SHEET_NAME, CELL_Z12)
			assert.Nil(t, err)
			assert.Equal(t, "TestValueZ12", value)

			file.Close()
		}
	})
}
